# AGPL 3 or any later version
# Modern Dark Upload Image Plugin for BDServer
# Provides a modern interface for uploading images

PluginData = {
    "author":{
        "title":"Madiator2011",
        "url":"https://shark.madiator.com/@madiator2011",
        "avatar":"https://shark.madiator.com/proxy/avatar.webp?url=https%3A%2F%2Fshark.madiator.com%2Ffiles%2F8076a50d-49db-4632-9d21-2e93ed53c500&avatar=1"
    },
    "title":"Modern Upload",
    "description":"Make your image upload look less ugly.",
    "license":"AGPL-3.0-or-later"}

def onHTML(server, html):
    """
    Enhance HTML for upload_image page with modern dark styling
    """
    
    # Only modify upload_image pages (both form and success)
    if not (server.path.startswith('/upload_image') or 'upload_image' in server.path):
        return html
    
    # First, let's add the missing closing tags to fix the HTML structure
    if '</body>' not in html:
        html = html + '</center></body></html>'
    
    # Modern dark upload styles
    modern_upload_styles = '''
<style>
/* Reset and base styles */
* {
    box-sizing: border-box;
}

body {
    margin: 0 !important;
    padding: 0 !important;
    font-family: system-ui, -apple-system, sans-serif !important;
    background: linear-gradient(135deg, #0f1419 0%, #1a1a2e 50%, #16213e 100%) !important;
    min-height: 100vh !important;
    display: flex !important;
    flex-direction: column !important;
    color: #ffffff !important;
}

/* Hide the original navigation button */
body > a.button:first-of-type {
    display: none !important;
}

/* Hide original elements */
center,
.middle_section_article,
.checklist_section_article,
.dark_box {
    display: none !important;
}

/* Modern Dark Upload Container */
.upload-container {
    flex: 1 !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
    padding: 20px !important;
}

.upload-card {
    background: rgba(30, 30, 46, 0.95) !important;
    backdrop-filter: blur(20px) !important;
    border: 1px solid rgba(255, 255, 255, 0.1) !important;
    border-radius: 12px !important;
    box-shadow: 0 25px 50px rgba(0, 0, 0, 0.5) !important;
    padding: 40px !important;
    width: 100% !important;
    max-width: 600px !important;
    position: relative !important;
    overflow: hidden !important;
}

.upload-card::before {
    content: '' !important;
    position: absolute !important;
    top: 0 !important;
    left: 0 !important;
    right: 0 !important;
    height: 3px !important;
    background: linear-gradient(90deg, #4c9eff, #7c3aed, #ec4899) !important;
}

.upload-header {
    text-align: center !important;
    margin-bottom: 32px !important;
}

.upload-title {
    font-size: 28px !important;
    font-weight: 700 !important;
    color: #ffffff !important;
    margin: 0 0 8px 0 !important;
    letter-spacing: -0.025em !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
    gap: 12px !important;
}

.upload-title img {
    width: 32px !important;
    height: 32px !important;
    filter: brightness(0) invert(1) !important;
}

.upload-subtitle {
    color: #94a3b8 !important;
    font-size: 16px !important;
    margin: 0 !important;
}

/* Drop Zone */
.upload-drop-zone {
    border: 2px dashed #374151 !important;
    border-radius: 12px !important;
    padding: 48px 24px !important;
    text-align: center !important;
    background: rgba(31, 41, 55, 0.5) !important;
    transition: all 0.3s ease !important;
    cursor: pointer !important;
    position: relative !important;
    overflow: hidden !important;
    margin-bottom: 24px !important;
    display: block !important;
}

.upload-drop-zone:hover {
    border-color: #4c9eff !important;
    background: rgba(76, 158, 255, 0.1) !important;
    transform: translateY(-2px) !important;
}

.upload-drop-zone input[type="file"] {
    position: absolute !important;
    left: 0 !important;
    top: 0 !important;
    width: 100% !important;
    height: 100% !important;
    opacity: 0 !important;
    cursor: pointer !important;
    z-index: 10 !important;
}

.upload-drop-content {
    pointer-events: none !important;
    position: relative !important;
    z-index: 1 !important;
}

.upload-drop-icon {
    width: 64px !important;
    height: 64px !important;
    margin: 0 auto 16px !important;
    filter: brightness(0) invert(1) opacity(0.6) !important;
    transition: all 0.3s ease !important;
}

.upload-drop-zone:hover .upload-drop-icon {
    filter: brightness(0) invert(1) sepia(1) saturate(5) hue-rotate(200deg) !important;
    transform: scale(1.1) !important;
}

.upload-drop-text {
    font-size: 18px !important;
    font-weight: 600 !important;
    color: #e2e8f0 !important;
    margin: 0 0 8px 0 !important;
}

.upload-drop-hint {
    font-size: 14px !important;
    color: #94a3b8 !important;
    margin: 0 !important;
}

/* Upload Button */
.upload-button {
    width: 100% !important;
    padding: 16px 24px !important;
    background: linear-gradient(135deg, #4c9eff 0%, #7c3aed 100%) !important;
    color: #ffffff !important;
    border: none !important;
    border-radius: 8px !important;
    font-size: 16px !important;
    font-weight: 600 !important;
    cursor: pointer !important;
    transition: all 0.2s ease !important;
    margin-top: 8px !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
    gap: 8px !important;
    text-decoration: none !important;
    position: relative !important;
    overflow: hidden !important;
}

.upload-button:hover {
    transform: translateY(-2px) !important;
    box-shadow: 0 10px 25px rgba(76, 158, 255, 0.4) !important;
}

.upload-button:active {
    transform: translateY(0) !important;
}

.upload-button:focus {
    outline: 2px solid #4c9eff !important;
    outline-offset: 2px !important;
}

.upload-button img {
    width: 18px !important;
    height: 18px !important;
    filter: brightness(0) invert(1) !important;
}

/* Cancel Link */
.cancel-link {
    display: inline-flex !important;
    align-items: center !important;
    gap: 8px !important;
    color: #94a3b8 !important;
    text-decoration: none !important;
    font-weight: 500 !important;
    padding: 14px 24px !important;
    border-radius: 8px !important;
    transition: all 0.2s ease !important;
    width: 100% !important;
    justify-content: center !important;
    margin-top: 16px !important;
    box-sizing: border-box !important;
}

.cancel-link:hover {
    background: rgba(148, 163, 184, 0.1) !important;
    color: #e2e8f0 !important;
    transform: translateY(-1px) !important;
}

.cancel-link img {
    width: 16px !important;
    height: 16px !important;
    filter: brightness(0) invert(1) opacity(0.7) !important;
}

/* File Types Info */
.file-types-info {
    background: rgba(76, 158, 255, 0.1) !important;
    border: 1px solid #4c9eff !important;
    border-radius: 8px !important;
    padding: 16px !important;
    margin-bottom: 24px !important;
    text-align: center !important;
}

.file-types-title {
    margin: 0 0 8px 0 !important;
    color: #4c9eff !important;
    font-size: 16px !important;
    font-weight: 600 !important;
}

.file-types-list {
    margin: 0 !important;
    color: #94a3b8 !important;
    font-size: 14px !important;
    line-height: 1.5 !important;
}

/* Responsive Design */
@media (max-width: 480px) {
    .upload-container {
        padding: 16px !important;
    }
    
    .upload-card {
        padding: 24px !important;
        margin: 0 !important;
    }
    
    .upload-title {
        font-size: 24px !important;
    }
    
    .upload-drop-zone {
        padding: 32px 16px !important;
    }
    
    .upload-drop-icon {
        width: 48px !important;
        height: 48px !important;
    }
}

/* Show our custom content */
.modern-upload-content {
    display: block !important;
}

/* Focus management for accessibility */
.upload-button:focus-visible,
.cancel-link:focus-visible {
    outline: 2px solid #4c9eff !important;
    outline-offset: 2px !important;
}

/* High contrast mode support */
@media (prefers-contrast: high) {
    .upload-card {
        border: 2px solid #ffffff !important;
        background: #000000 !important;
    }
    
    .upload-button {
        background: #ffffff !important;
        color: #000000 !important;
        border: 2px solid #ffffff !important;
    }
}

/* Reduced motion support */
@media (prefers-reduced-motion: reduce) {
    * {
        animation-duration: 0.01ms !important;
        animation-iteration-count: 1 !important;
        transition-duration: 0.01ms !important;
    }
}

/* Screen reader improvements */
.sr-only {
    position: absolute !important;
    width: 1px !important;
    height: 1px !important;
    padding: 0 !important;
    margin: -1px !important;
    overflow: hidden !important;
    clip: rect(0, 0, 0, 0) !important;
    white-space: nowrap !important;
    border: 0 !important;
}

/* Form Groups */
.form-group {
    margin-bottom: 24px !important;
    position: relative !important;
}

.form-label {
    display: block !important;
    font-weight: 600 !important;
    color: #e2e8f0 !important;
    margin-bottom: 8px !important;
    font-size: 14px !important;
}

.form-input {
    width: 100% !important;
    padding: 14px 16px !important;
    border: 2px solid #374151 !important;
    border-radius: 8px !important;
    font-size: 16px !important;
    transition: all 0.2s ease !important;
    background: #1f2937 !important;
    color: #ffffff !important;
    box-sizing: border-box !important;
}

.form-input::placeholder {
    color: #6b7280 !important;
}

.form-input:focus {
    outline: none !important;
    border-color: #4c9eff !important;
    box-shadow: 0 0 0 3px rgba(76, 158, 255, 0.2) !important;
    background: #111827 !important;
}

/* Success page specific styling */
.success-form-group {
    margin-bottom: 28px !important;
    position: relative !important;
}

.success-form-label {
    display: block !important;
    font-weight: 600 !important;
    color: #e2e8f0 !important;
    margin-bottom: 12px !important;
    font-size: 15px !important;
    padding-left: 4px !important;
}

.success-form-input {
    width: 100% !important;
    padding: 16px 20px !important;
    border: 2px solid #374151 !important;
    border-radius: 8px !important;
    font-size: 14px !important;
    font-family: 'Courier New', Consolas, monospace !important;
    transition: all 0.2s ease !important;
    background: #1f2937 !important;
    color: #ffffff !important;
    box-sizing: border-box !important;
    cursor: text !important;
    line-height: 1.4 !important;
    word-break: break-all !important;
}

.success-form-input:focus {
    outline: none !important;
    border-color: #4c9eff !important;
    box-shadow: 0 0 0 3px rgba(76, 158, 255, 0.2) !important;
    background: #111827 !important;
}

.success-form-input:hover {
    border-color: #4b5563 !important;
}

/* Copy hint text */
.copy-hint {
    color: #6b7280 !important;
    font-size: 12px !important;
    margin-top: 6px !important;
    display: block !important;
    font-style: italic !important;
}
</style>
'''
    
    # Insert modern styles before closing head tag
    html = html.replace('</head>', modern_upload_styles + '</head>')
    
    # Determine if this is upload form or success page
    if 'Image URL' in html or 'Markdown Embed code' in html:
        # This is the success page
        html = add_modern_success_content(html, server)
    else:
        # This is the upload form page
        html = add_modern_upload_content(html, server)
    
    return html


def add_modern_upload_content(html, server):
    """Add modern dark upload content to the page"""
    
    modern_upload_content = '''
    <div class="modern-upload-content">
        <div class="upload-container">
            <div class="upload-card">
                <div class="upload-header">
                    <h1 class="upload-title">
                        <img src="/icon/image_new" alt="">
                        Upload Image
                    </h1>
                    <p class="upload-subtitle">Share your images with the community</p>
                </div>
                
                <div class="file-types-info">
                    <h4 class="file-types-title">Supported Formats</h4>
                    <p class="file-types-list">
                        PNG, JPG, WebM, GIF • Maximum size: 3MB
                    </p>
                </div>
                
                <form action="upload_image_do" method="post" enctype="multipart/form-data" novalidate aria-labelledby="upload-form">
                    <h2 id="upload-form" class="sr-only">Image Upload Form</h2>
                    
                    <label for="fileInput" class="upload-drop-zone">
                        <input 
                            class="button"
                            name="file" 
                            type="file" 
                            required
                            accept=".png,.jpg,.webm,.gif"
                            aria-describedby="file-help"
                            id="fileInput"
                        >
                        <div class="upload-drop-content">
                            <img src="/icon/image" alt="" class="upload-drop-icon">
                            <p class="upload-drop-text">Click anywhere to select image</p>
                            <p class="upload-drop-hint">Choose a PNG, JPG, WebM, or GIF file</p>
                        </div>
                    </label>
                    
                    <button type="submit" class="upload-button" aria-describedby="upload-button-desc">
                        <img src="/icon/image_new" alt="">
                        Upload
                    </button>
                    <span id="upload-button-desc" class="sr-only">Submit form to upload the selected image</span>
                </form>
                
                <a href="/" class="cancel-link" aria-describedby="cancel-link-desc">
                    <img src="/icon/cancel" alt="">
                    Cancel
                </a>
                <span id="cancel-link-desc" class="sr-only">Cancel upload and return to homepage</span>
            </div>
        </div>
    </div>
    '''
    
    # Insert before the closing body tag
    html = html.replace('</body>', modern_upload_content + '</body>')
    
    return html


def add_modern_success_content(html, server):
    """Add modern dark success content for uploaded image"""
    
    # Extract image URL from original HTML
    import re
    image_match = re.search(r'<img src="([^"]+)">', html)
    image_url = image_match.group(1) if image_match else ""
    
    # Extract markdown embed code
    markdown_match = re.search(r'value="(\!\[Image\]\([^)]+\))"', html)
    markdown_code = markdown_match.group(1) if markdown_match else ""
    
    # Extract image URL from input
    url_match = re.search(r'Image URL.*?value="([^"]+)"', html, re.DOTALL)
    direct_url = url_match.group(1) if url_match else ""
    
    # Extract global URL
    global_match = re.search(r'Global Image URL.*?value="([^"]+)"', html, re.DOTALL)
    global_url = global_match.group(1) if global_match else ""
    
    modern_success_content = f'''
    <div class="modern-upload-content">
        <div class="upload-container">
            <div class="upload-card">
                <div class="upload-header">
                    <h1 class="upload-title">
                        <img src="/icon/ok" alt="">
                        Upload Successful!
                    </h1>
                    <p class="upload-subtitle">Your image has been uploaded and is ready to use</p>
                </div>
                
                <div style="text-align: center; margin-bottom: 32px;">
                    <img src="{image_url}" style="max-width: 100%; max-height: 300px; border-radius: 8px; box-shadow: 0 8px 24px rgba(0,0,0,0.3);" alt="Uploaded image">
                </div>
                
                <div class="success-form-group">
                    <label class="success-form-label">Markdown Embed Code</label>
                    <input 
                        class="success-form-input" 
                        value="{markdown_code}" 
                        readonly 
                    >
                    <small class="copy-hint">Use for embedding images in markdown text</small>
                </div>
                
                <div class="success-form-group">
                    <label class="success-form-label">Image URL</label>
                    <input 
                        class="success-form-input" 
                        value="{direct_url}" 
                        readonly 
                    >
                    <small class="copy-hint">Direct link to your image file</small>
                </div>
                
                <div class="success-form-group">
                    <label class="success-form-label">Global Image URL</label>
                    <input 
                        class="success-form-input" 
                        value="{global_url}" 
                        readonly 
                    >
                    <small class="copy-hint">Full URL accessible from anywhere on the internet</small>
                </div>
                
                <a href="/upload_image" class="upload-button" style="text-decoration: none; color: white;">
                    <img src="/icon/image_new" alt="">
                    Upload Another Image
                </a>
                
                <a href="/" class="cancel-link">
                    <img src="/icon/ok" alt="">
                    Done
                </a>
            </div>
        </div>
    </div>
    '''
    
    # Insert before the closing body tag
    html = html.replace('</body>', modern_success_content + '</body>')
    
    return html
